@@ -47,15 +47,14 @@ def load(hub, sources, dyne_names, cli):
         if name in dyne:
             if name not in raw:
                 raw[name] = {"CONFIG": {}, "CLI_CONFIG": {}}
-            if "CONFIG" in dyne[name]:
-                hub.pop.dicts.update(raw[name]["CONFIG"], dyne[name]["CONFIG"])
             if "CLI_CONFIG" in dyne[name]:
                 draw = {}
+                cli_draw = {}
                 for key, val in dyne[name]["CLI_CONFIG"].items():
                     if val.get("dyne"):
                         val["source"] = name
-                        draw[key] = val
-                hub.pop.dicts.update(raw[cli]["CLI_CONFIG"], draw)
+                        cli_draw[key] = val
+                hub.pop.dicts.update(raw[cli]["CLI_CONFIG"], cli_draw)
     raw = hub.config.inject.add(cli, raw)
     return raw
 
